diff --git a/BodyshopUploader/App.config b/BodyshopUploader/App.config
index 7986bd5..bf04cbe 100644
--- a/BodyshopUploader/App.config
+++ b/BodyshopUploader/App.config
@@ -2,7 +2,7 @@
-
+
@@ -41,7 +41,7 @@
-
+
@@ -84,6 +84,6 @@
C:\CIECA\CCC\IMPORT
-
+
diff --git a/BodyshopUploader/App.xaml b/BodyshopUploader/App.xaml
index d1ed206..adf7efa 100644
--- a/BodyshopUploader/App.xaml
+++ b/BodyshopUploader/App.xaml
@@ -1,7 +1,7 @@
-
/// Interaction logic for App.xaml
///
public partial class App : Application
{
- static Mutex mutex = new Mutex(false, "Rome Online Partner");
+ static Mutex mutex = new Mutex(false, "ProManager Partner");
App()
{
@@ -31,7 +31,7 @@ namespace RomeOnlinePartner
// of the program is in the process of shutting down.
if (!mutex.WaitOne(TimeSpan.FromSeconds(2), false))
{
- MessageBox.Show("Rome Online Partner is already running.");
+ MessageBox.Show("ProManager Partner is already running.");
App.Current.Shutdown();
return;
}
@@ -48,7 +48,7 @@ namespace RomeOnlinePartner
mutex.ReleaseMutex();
Utils.PowerModeEventHandler.DisposeEventHandler();
- RomeOnlinePartner.Properties.Settings.Default.Save();
+ ProManagerPartner.Properties.Settings.Default.Save();
Utils.QuickBooksInterop.DisconnectFromQuickBooks();
}
}
diff --git a/BodyshopUploader/Assets/favicon.ico b/BodyshopUploader/Assets/favicon.ico
index 2280b30..f0c442e 100644
Binary files a/BodyshopUploader/Assets/favicon.ico and b/BodyshopUploader/Assets/favicon.ico differ
diff --git a/BodyshopUploader/Assets/logo.png b/BodyshopUploader/Assets/logo.png
new file mode 100644
index 0000000..95f406e
Binary files /dev/null and b/BodyshopUploader/Assets/logo.png differ
diff --git a/BodyshopUploader/ImEXOnlinePartner.csproj b/BodyshopUploader/ImEXOnlinePartner.csproj
index 4e7f31e..4c6242c 100644
--- a/BodyshopUploader/ImEXOnlinePartner.csproj
+++ b/BodyshopUploader/ImEXOnlinePartner.csproj
@@ -6,8 +6,8 @@
AnyCPU
{76B98E9B-A33A-464F-A07B-56E773376543}
WinExe
- RomeOnlinePartner
- RomeOnlinePartner
+ ProManagerPartner
+ ProManagerPartner
v4.8
512
{60dc8134-eba5-43b8-bcc9-bb4bc16c2548};{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}
@@ -54,7 +54,7 @@
4
- Assets\ro-favicon.ico
+ Assets\favicon.ico
true
@@ -80,7 +80,7 @@
- RomeOnlinePartner.App
+ ProManagerPartner.App
bin\Test\
@@ -271,8 +271,7 @@
-
-
+
PreserveNewest
@@ -561,7 +560,7 @@
-
-
+
+
\ No newline at end of file
diff --git a/BodyshopUploader/Models/Bodyshop.cs b/BodyshopUploader/Models/Bodyshop.cs
index 824cca6..f29a824 100644
--- a/BodyshopUploader/Models/Bodyshop.cs
+++ b/BodyshopUploader/Models/Bodyshop.cs
@@ -5,7 +5,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace RomeOnlinePartner.Models
+namespace ProManagerPartner.Models
{
[JsonConverter(typeof(Utils.JsonPathConverter))]
public class Bodyshop : DTO_Base
diff --git a/BodyshopUploader/Models/DTO_Base.cs b/BodyshopUploader/Models/DTO_Base.cs
index 6443f2b..e2199ca 100644
--- a/BodyshopUploader/Models/DTO_Base.cs
+++ b/BodyshopUploader/Models/DTO_Base.cs
@@ -6,7 +6,7 @@ using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
-namespace RomeOnlinePartner.Models
+namespace ProManagerPartner.Models
{
public abstract class DTO_Base : INotifyPropertyChanged
{
diff --git a/BodyshopUploader/Models/DTO_QueueItem.cs b/BodyshopUploader/Models/DTO_QueueItem.cs
index d2966ad..3802ddb 100644
--- a/BodyshopUploader/Models/DTO_QueueItem.cs
+++ b/BodyshopUploader/Models/DTO_QueueItem.cs
@@ -4,7 +4,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace RomeOnlinePartner
+namespace ProManagerPartner
{
public enum SourceSystem
{
@@ -14,7 +14,7 @@ namespace RomeOnlinePartner
}
}
-namespace RomeOnlinePartner.Models
+namespace ProManagerPartner.Models
{
public class DTO_QueueItem : DTO_Base
{
diff --git a/BodyshopUploader/Models/Monitor.cs b/BodyshopUploader/Models/Monitor.cs
index c6afc12..896a6ab 100644
--- a/BodyshopUploader/Models/Monitor.cs
+++ b/BodyshopUploader/Models/Monitor.cs
@@ -4,7 +4,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace RomeOnlinePartner.Models
+namespace ProManagerPartner.Models
{
public class Monitor : DTO_Base
{
diff --git a/BodyshopUploader/Models/QbRequestItem.cs b/BodyshopUploader/Models/QbRequestItem.cs
index 67bc872..3c7ff2d 100644
--- a/BodyshopUploader/Models/QbRequestItem.cs
+++ b/BodyshopUploader/Models/QbRequestItem.cs
@@ -5,7 +5,7 @@ using System.Text;
using System.Threading.Tasks;
using Newtonsoft.Json;
-namespace RomeOnlinePartner.Models
+namespace ProManagerPartner.Models
{
public class QbRequestItem : DTO_Base
{
diff --git a/BodyshopUploader/Models/QbResponseItem.cs b/BodyshopUploader/Models/QbResponseItem.cs
index 40acadc..5932793 100644
--- a/BodyshopUploader/Models/QbResponseItem.cs
+++ b/BodyshopUploader/Models/QbResponseItem.cs
@@ -5,7 +5,7 @@ using System.Text;
using System.Threading.Tasks;
using Newtonsoft.Json;
-namespace RomeOnlinePartner.Models
+namespace ProManagerPartner.Models
{
public class QbResponseItem : DTO_Base
{
diff --git a/BodyshopUploader/Models/QbXmlResponse.cs b/BodyshopUploader/Models/QbXmlResponse.cs
index 2e4ae6e..bf6c38c 100644
--- a/BodyshopUploader/Models/QbXmlResponse.cs
+++ b/BodyshopUploader/Models/QbXmlResponse.cs
@@ -5,7 +5,7 @@ using System.Text;
using System.Threading.Tasks;
using System.Xml.Linq;
-namespace RomeOnlinePartner.Models
+namespace ProManagerPartner.Models
{
public class QbXmlResponse : DTO_Base
{
diff --git a/BodyshopUploader/Models/ScanResponseItem.cs b/BodyshopUploader/Models/ScanResponseItem.cs
index 042a2f5..09d7c62 100644
--- a/BodyshopUploader/Models/ScanResponseItem.cs
+++ b/BodyshopUploader/Models/ScanResponseItem.cs
@@ -5,7 +5,7 @@ using System.Text;
using System.Threading.Tasks;
using Newtonsoft.Json;
-namespace RomeOnlinePartner.Models
+namespace ProManagerPartner.Models
{
public class ScanResponseItem : DTO_Base
{
diff --git a/BodyshopUploader/RomeOnlinePartner.nuspec b/BodyshopUploader/ProManagerPartner.nuspec
similarity index 70%
rename from BodyshopUploader/RomeOnlinePartner.nuspec
rename to BodyshopUploader/ProManagerPartner.nuspec
index 5d07a70..d6e2e32 100644
--- a/BodyshopUploader/RomeOnlinePartner.nuspec
+++ b/BodyshopUploader/ProManagerPartner.nuspec
@@ -1,15 +1,15 @@
- RomeOnlinePartner
+ ProManagerPartner
1.0.0
- Rome Online Partner
+ ProManager Partner
ImEX Systems Inc.
false
- https://s3.us-east-2.amazonaws.com/partner.romeonline.io/favicon.ico
+ https://s3.us-east-2.amazonaws.com/partner.promanager.web-est.com/favicon.ico
ImEX Systems Inc.
- Rome Online Partner
+ ProManager Partner
diff --git a/BodyshopUploader/Properties/AssemblyInfo.cs b/BodyshopUploader/Properties/AssemblyInfo.cs
index 451913d..12c75f5 100644
--- a/BodyshopUploader/Properties/AssemblyInfo.cs
+++ b/BodyshopUploader/Properties/AssemblyInfo.cs
@@ -7,11 +7,11 @@ using System.Windows;
// General Information about an assembly is controlled through the following
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
-[assembly: AssemblyTitle("Rome Online Partner")]
+[assembly: AssemblyTitle("ProManager Partner")]
[assembly: AssemblyDescription("")]
[assembly: AssemblyConfiguration("")]
-[assembly: AssemblyCompany("Rome Technologies")]
-[assembly: AssemblyProduct("Rome Online Partner")]
+[assembly: AssemblyCompany("Web-Est")]
+[assembly: AssemblyProduct("ProManager Partner")]
[assembly: AssemblyCopyright("Copyright © ImEX Systems Inc.")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]
diff --git a/BodyshopUploader/Properties/Resources.resx b/BodyshopUploader/Properties/Resources.resx
index 4d938a3..0fda816 100644
--- a/BodyshopUploader/Properties/Resources.resx
+++ b/BodyshopUploader/Properties/Resources.resx
@@ -253,7 +253,7 @@
QuickBooks Connection
- Please do not close Rome Online or Rome Partner during the connection process.
+ Please do not close ProManager or ProManager Partner during the connection process.
QuickBooks Connection Request
@@ -268,13 +268,13 @@
Password
- Login - Rome Online Partner
+ Login - ProManager Partner
- Rome Online Partner
+ ProManager Partner
- Rome Online Partner | Rome Technologies
+ ProManager Partner | Web-Est
Username
diff --git a/BodyshopUploader/Properties/Settings.Designer.cs b/BodyshopUploader/Properties/Settings.Designer.cs
index 78c3fbe..abd4ea3 100644
--- a/BodyshopUploader/Properties/Settings.Designer.cs
+++ b/BodyshopUploader/Properties/Settings.Designer.cs
@@ -8,7 +8,7 @@
//
//------------------------------------------------------------------------------
-namespace RomeOnlinePartner.Properties {
+namespace ProManagerPartner.Properties {
[global::System.Runtime.CompilerServices.CompilerGeneratedAttribute()]
diff --git a/BodyshopUploader/Properties/Settings.settings b/BodyshopUploader/Properties/Settings.settings
index a448122..eab270b 100644
--- a/BodyshopUploader/Properties/Settings.settings
+++ b/BodyshopUploader/Properties/Settings.settings
@@ -1,5 +1,5 @@
-
+
diff --git a/BodyshopUploader/Releases/RELEASES b/BodyshopUploader/Releases/RELEASES
index 01e1337..1b295ab 100644
--- a/BodyshopUploader/Releases/RELEASES
+++ b/BodyshopUploader/Releases/RELEASES
@@ -1,7 +1 @@
-21080F2A8D8BEC1B0EAD01141BBBC56A69E120EB RomeOnlinePartner-1.1.0-full.nupkg 5957137
-9E08BA6C1E2DB1295696713165AB25AADE94875F RomeOnlinePartner-1.1.1-delta.nupkg 98643
-26F725C795EC01893BC36E5FC59F4ADFD390F88A RomeOnlinePartner-1.1.1-full.nupkg 5958856
-637F563749852E516AF4D41E30324FB04499D205 RomeOnlinePartner-1.1.2-delta.nupkg 88517
-A1110AE679B0ABAD08129B41C12399C3C588ABC9 RomeOnlinePartner-1.1.2-full.nupkg 5962013
-BF0B893BC82219F385D83F44994D26AE0D3619CF RomeOnlinePartner-1.1.3-delta.nupkg 64235
-DB8DCD6BD2B3F4CA790A8B25E8DD495144D1D196 RomeOnlinePartner-1.1.3-full.nupkg 5967310
\ No newline at end of file
+8D61826DD6D6B26138D14962BBA992259C9A2FE9 ProManagerPartner-1.1.3-full.nupkg 5998889
\ No newline at end of file
diff --git a/BodyshopUploader/Utils/ARMSRoData.cs b/BodyshopUploader/Utils/ARMSRoData.cs
index 93107be..12ea8c1 100644
--- a/BodyshopUploader/Utils/ARMSRoData.cs
+++ b/BodyshopUploader/Utils/ARMSRoData.cs
@@ -10,7 +10,7 @@ using GraphQL;
using Newtonsoft;
using Newtonsoft.Json.Linq;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class ARMSRoData
{
diff --git a/BodyshopUploader/Utils/ARMSRoDataModel.cs b/BodyshopUploader/Utils/ARMSRoDataModel.cs
index 883e2ef..37af160 100644
--- a/BodyshopUploader/Utils/ARMSRoDataModel.cs
+++ b/BodyshopUploader/Utils/ARMSRoDataModel.cs
@@ -5,7 +5,7 @@ using System.Text;
using System.Threading.Tasks;
using FileHelpers;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
diff --git a/BodyshopUploader/Utils/AppMetaData.cs b/BodyshopUploader/Utils/AppMetaData.cs
index 9ca07d6..814a2cb 100644
--- a/BodyshopUploader/Utils/AppMetaData.cs
+++ b/BodyshopUploader/Utils/AppMetaData.cs
@@ -6,7 +6,7 @@ using System.Threading.Tasks;
using System.Windows;
using System.IO;
using RestSharp;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class AppMetaData
{
@@ -22,7 +22,7 @@ namespace RomeOnlinePartner.Utils
public static Boolean IsTest = false;
private static string workingDirectory = Path.GetDirectoryName(System.Reflection.Assembly.GetExecutingAssembly().Location);
- public static string globalScriptsPath = @"C:\Rome\PartnerScripts";
+ public static string globalScriptsPath = @"C:\Web-Est\PartnerScripts";
public static RestClient RestClient;
diff --git a/BodyshopUploader/Utils/ApplicationExceptionHandler.cs b/BodyshopUploader/Utils/ApplicationExceptionHandler.cs
index 6b5bca4..aba8793 100644
--- a/BodyshopUploader/Utils/ApplicationExceptionHandler.cs
+++ b/BodyshopUploader/Utils/ApplicationExceptionHandler.cs
@@ -4,7 +4,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class ApplicationExceptionHandler
{
diff --git a/BodyshopUploader/Utils/Auth.cs b/BodyshopUploader/Utils/Auth.cs
index 1882d15..6264012 100644
--- a/BodyshopUploader/Utils/Auth.cs
+++ b/BodyshopUploader/Utils/Auth.cs
@@ -6,7 +6,7 @@ using System.Threading.Tasks;
using Firebase.Auth;
using System.Timers;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class Auth
{
diff --git a/BodyshopUploader/Utils/BaseModel.cs b/BodyshopUploader/Utils/BaseModel.cs
index 554b994..66262be 100644
--- a/BodyshopUploader/Utils/BaseModel.cs
+++ b/BodyshopUploader/Utils/BaseModel.cs
@@ -3,7 +3,7 @@ using System.ComponentModel;
using System.Runtime.CompilerServices;
-namespace RomeOnlinePartner
+namespace ProManagerPartner
{
public class BaseModel : INotifyPropertyChanged
{
diff --git a/BodyshopUploader/Utils/BaseViewModel.cs b/BodyshopUploader/Utils/BaseViewModel.cs
index 89807ff..b8b534e 100644
--- a/BodyshopUploader/Utils/BaseViewModel.cs
+++ b/BodyshopUploader/Utils/BaseViewModel.cs
@@ -2,7 +2,7 @@
using System.ComponentModel;
using System.Runtime.CompilerServices;
-namespace RomeOnlinePartner
+namespace ProManagerPartner
{
public abstract class BaseViewModel : INotifyPropertyChanged
{
diff --git a/BodyshopUploader/Utils/CCCPartsPriceChange.cs b/BodyshopUploader/Utils/CCCPartsPriceChange.cs
index 85cf0fc..768618c 100644
--- a/BodyshopUploader/Utils/CCCPartsPriceChange.cs
+++ b/BodyshopUploader/Utils/CCCPartsPriceChange.cs
@@ -8,7 +8,7 @@ using System.Threading.Tasks;
using DotNetDBF;
using Newtonsoft.Json.Linq;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
class CCCPartsPriceChange
{
diff --git a/BodyshopUploader/Utils/CIECAMonitor.cs b/BodyshopUploader/Utils/CIECAMonitor.cs
index fe13e3e..faa19c5 100644
--- a/BodyshopUploader/Utils/CIECAMonitor.cs
+++ b/BodyshopUploader/Utils/CIECAMonitor.cs
@@ -4,9 +4,9 @@ using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
-using RomeOnlinePartner.Models;
+using ProManagerPartner.Models;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public class CIECAMonitor : FileSystemWatcher
{
diff --git a/BodyshopUploader/Utils/Decoder/EstimateDecoder.cs b/BodyshopUploader/Utils/Decoder/EstimateDecoder.cs
index 74b2964..484bda1 100644
--- a/BodyshopUploader/Utils/Decoder/EstimateDecoder.cs
+++ b/BodyshopUploader/Utils/Decoder/EstimateDecoder.cs
@@ -8,7 +8,7 @@ using System.Threading.Tasks;
using DotNetDBF;
using Newtonsoft.Json.Linq;
-namespace RomeOnlinePartner.Utils.Decoder
+namespace ProManagerPartner.Utils.Decoder
{
class EstimateDecoder
{
diff --git a/BodyshopUploader/Utils/DiskScan.cs b/BodyshopUploader/Utils/DiskScan.cs
index 37085c5..31c1a04 100644
--- a/BodyshopUploader/Utils/DiskScan.cs
+++ b/BodyshopUploader/Utils/DiskScan.cs
@@ -1,4 +1,4 @@
-using RomeOnlinePartner.Models;
+using ProManagerPartner.Models;
using System;
using System.Collections.Generic;
using System.IO;
@@ -6,7 +6,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Newtonsoft.Json.Linq;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class DiskScan
{
diff --git a/BodyshopUploader/Utils/GraphQL.cs b/BodyshopUploader/Utils/GraphQL.cs
index a47a160..66ad589 100644
--- a/BodyshopUploader/Utils/GraphQL.cs
+++ b/BodyshopUploader/Utils/GraphQL.cs
@@ -11,7 +11,7 @@ using System.Net.Http;
using Newtonsoft;
using Newtonsoft.Json.Linq;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class GraphQL
{
diff --git a/BodyshopUploader/Utils/Growls/GrowlNotification.xaml b/BodyshopUploader/Utils/Growls/GrowlNotification.xaml
index 04c503d..e06fe6c 100644
--- a/BodyshopUploader/Utils/Growls/GrowlNotification.xaml
+++ b/BodyshopUploader/Utils/Growls/GrowlNotification.xaml
@@ -1,9 +1,9 @@
-
{
- hlog("Received a QuickBooks request from Rome Online");
+ hlog("Received a QuickBooks request from ProManager");
res.WithCORS();
res.Close();
}, "OPTIONS");
@@ -41,7 +41,7 @@ namespace RomeOnlinePartner.Utils
//Pinging based routes.
Route.Add("/ping/", (req, res, props) =>
{
- hlog("Received a ping from Rome Online");
+ hlog("Received a ping from ProManager");
res.WithCORS();
res.Close();
}, "OPTIONS");
@@ -52,7 +52,7 @@ namespace RomeOnlinePartner.Utils
//FileScanning Routes
Route.Add("/scan/", (req, res, props) =>
{
- hlog("Received a scan request from Rome Online");
+ hlog("Received a scan request from ProManager");
res.WithCORS();
res.Close();
}, "OPTIONS");
@@ -61,7 +61,7 @@ namespace RomeOnlinePartner.Utils
, "POST");
Route.Add("/import/", (req, res, props) =>
{
- hlog("Received an import request from Rome Online");
+ hlog("Received an import request from ProManager");
res.WithCORS();
res.Close();
}, "OPTIONS");
@@ -71,7 +71,7 @@ namespace RomeOnlinePartner.Utils
Route.Add("/oec/", (req, res, props) =>
{
- hlog("Received an OEC from Rome Online");
+ hlog("Received an OEC from ProManager");
res.WithCORS();
res.Close();
}, "OPTIONS");
@@ -81,7 +81,7 @@ namespace RomeOnlinePartner.Utils
Route.Add("/ppc/", (req, res, props) =>
{
- hlog("Received an PPC from Rome Online");
+ hlog("Received an PPC from ProManager");
res.WithCORS();
res.Close();
}, "OPTIONS");
@@ -118,17 +118,17 @@ namespace RomeOnlinePartner.Utils
hlog = HttpLogger;
try
{
- hlog("Rome Online connection server starting...");
+ hlog("ProManager connection server starting...");
HttpServer.ListenAsync(1337, token, Route.OnHttpRequestAsync).Wait();
}
catch (Exception Ex)
{
logger.Fatal("Unable to start HTTP server. " + Ex.ToString());
- hlog("Rome Online connection server could not start. Please restart the partner to try again.");
+ hlog("ProManager connection server could not start. Please restart the partner to try again.");
App.Current.Dispatcher.Invoke(() =>
{
- string msg = "Unable to connect to Rome Online Web App. Please ensure your firewall allows the connection.";
+ string msg = "Unable to connect to ProManager Web App. Please ensure your firewall allows the connection.";
Utils.Notifications.notifier.ShowError(msg);
});
Utils.SquirrelAwareHelper.AddHttpExcetion();
@@ -197,7 +197,7 @@ namespace RomeOnlinePartner.Utils
{
try
{
- hlog("Processing QuickBooks request. Rome Online Record ID:" + request.Id);
+ hlog("Processing QuickBooks request. ProManager Record ID:" + request.Id);
XDocument response = XDocument.Parse(QuickBooksInterop.ProcessQBXmlRequestUnManaged(request.QbXML));
QbXmlResponse ResponseStatus = QuickBooksInterop.ParseResponseXml(response);
diff --git a/BodyshopUploader/Utils/JobProcessingQueue.cs b/BodyshopUploader/Utils/JobProcessingQueue.cs
index d5ba11b..a0dbaea 100644
--- a/BodyshopUploader/Utils/JobProcessingQueue.cs
+++ b/BodyshopUploader/Utils/JobProcessingQueue.cs
@@ -5,14 +5,14 @@ using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
-using RomeOnlinePartner.Utils;
-using RomeOnlinePartner.Models;
-using RomeOnlinePartner.Utils.Growls;
+using ProManagerPartner.Utils;
+using ProManagerPartner.Models;
+using ProManagerPartner.Utils.Growls;
using GraphQL;
using Newtonsoft.Json.Linq;
using ToastNotifications.Messages;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class JobProcessingQueue
{
diff --git a/BodyshopUploader/Utils/JsonConverter.cs b/BodyshopUploader/Utils/JsonConverter.cs
index 9cb3b4b..c9dc8a9 100644
--- a/BodyshopUploader/Utils/JsonConverter.cs
+++ b/BodyshopUploader/Utils/JsonConverter.cs
@@ -7,7 +7,7 @@ using System.Reflection;
using System.Text;
using System.Threading.Tasks;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
class JsonPathConverter : JsonConverter
{
diff --git a/BodyshopUploader/Utils/JsonExtensions.cs b/BodyshopUploader/Utils/JsonExtensions.cs
index 2f2bb83..a79e507 100644
--- a/BodyshopUploader/Utils/JsonExtensions.cs
+++ b/BodyshopUploader/Utils/JsonExtensions.cs
@@ -5,7 +5,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class JsonExtensions
{
diff --git a/BodyshopUploader/Utils/LoginHelpers.cs b/BodyshopUploader/Utils/LoginHelpers.cs
index 5953af4..2c7b339 100644
--- a/BodyshopUploader/Utils/LoginHelpers.cs
+++ b/BodyshopUploader/Utils/LoginHelpers.cs
@@ -6,7 +6,7 @@ using System.Security;
using System.Text;
using System.Threading.Tasks;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class LoginHelpers
{
diff --git a/BodyshopUploader/Utils/Notifications.cs b/BodyshopUploader/Utils/Notifications.cs
index 751f2e1..ab72c2b 100644
--- a/BodyshopUploader/Utils/Notifications.cs
+++ b/BodyshopUploader/Utils/Notifications.cs
@@ -9,7 +9,7 @@ using ToastNotifications.Position;
using ToastNotifications.Messages;
using System.Windows;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class Notifications
{
diff --git a/BodyshopUploader/Utils/OEConnection.cs b/BodyshopUploader/Utils/OEConnection.cs
index 1e8a43f..b37def9 100644
--- a/BodyshopUploader/Utils/OEConnection.cs
+++ b/BodyshopUploader/Utils/OEConnection.cs
@@ -8,7 +8,7 @@ using System.Threading.Tasks;
using DotNetDBF;
using Newtonsoft.Json.Linq;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class OEConnection
{
diff --git a/BodyshopUploader/Utils/PPGMixData.cs b/BodyshopUploader/Utils/PPGMixData.cs
index 9f342f5..0965c39 100644
--- a/BodyshopUploader/Utils/PPGMixData.cs
+++ b/BodyshopUploader/Utils/PPGMixData.cs
@@ -10,7 +10,7 @@ using System.IO;
using System.Timers;
using RestSharp;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class PPGMixData
{
@@ -194,7 +194,7 @@ v_paint_codes
new XElement("TransactionDate", DateTime.Now.ToString("yyyy-MM-hh:mm:ss"))
),
new XElement("Product",
- new XElement("Name", "Rome Online"),
+ new XElement("Name", "ProManager"),
new XElement("Version", null)
)
diff --git a/BodyshopUploader/Utils/PowerModeEventHandler.cs b/BodyshopUploader/Utils/PowerModeEventHandler.cs
index e99385d..5aee1cf 100644
--- a/BodyshopUploader/Utils/PowerModeEventHandler.cs
+++ b/BodyshopUploader/Utils/PowerModeEventHandler.cs
@@ -6,7 +6,7 @@ using System.Text;
using System.Threading.Tasks;
using System.Windows;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class PowerModeEventHandler
{
diff --git a/BodyshopUploader/Utils/Queries/JobsQueries.cs b/BodyshopUploader/Utils/Queries/JobsQueries.cs
index 40ccd47..93b65ab 100644
--- a/BodyshopUploader/Utils/Queries/JobsQueries.cs
+++ b/BodyshopUploader/Utils/Queries/JobsQueries.cs
@@ -5,7 +5,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace RomeOnlinePartner.Utils.Queries
+namespace ProManagerPartner.Utils.Queries
{
class JobsQueries
{
diff --git a/BodyshopUploader/Utils/Queries/VehicleQueries.cs b/BodyshopUploader/Utils/Queries/VehicleQueries.cs
index 45f831a..ecf7c63 100644
--- a/BodyshopUploader/Utils/Queries/VehicleQueries.cs
+++ b/BodyshopUploader/Utils/Queries/VehicleQueries.cs
@@ -5,7 +5,7 @@ using System.Linq;
using System.Text;
using System.Threading.Tasks;
-namespace RomeOnlinePartner.Utils.Queries
+namespace ProManagerPartner.Utils.Queries
{
public static class VehicleQueries
{
diff --git a/BodyshopUploader/Utils/QuickBooksInterop.cs b/BodyshopUploader/Utils/QuickBooksInterop.cs
index 5e0b93b..e4cd384 100644
--- a/BodyshopUploader/Utils/QuickBooksInterop.cs
+++ b/BodyshopUploader/Utils/QuickBooksInterop.cs
@@ -6,12 +6,12 @@ using System.Text;
using System.Threading.Tasks;
using System.Xml;
using System.Xml.Linq;
-using RomeOnlinePartner.Utils.Growls;
+using ProManagerPartner.Utils.Growls;
using Interop.QBFC16;
using Interop.QBXMLRP2;
using ToastNotifications.Messages;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class QuickBooksInterop
{
@@ -20,8 +20,8 @@ namespace RomeOnlinePartner.Utils
private static RequestProcessor2 rp;
private static string maxVersion;
private static QBFileMode mode = QBFileMode.qbFileOpenDoNotCare;
- private static string appID = "RomePartner";
- private static string appName = "RomeOnlinePartner";
+ private static string appID = "ProManagerPartner";
+ private static string appName = "ProManagerPartner";
private static GrowlNotification Growler;
public static void ConnectToQuickBooks()
diff --git a/BodyshopUploader/Utils/RelayCommand.cs b/BodyshopUploader/Utils/RelayCommand.cs
index 44cfade..4d6a601 100644
--- a/BodyshopUploader/Utils/RelayCommand.cs
+++ b/BodyshopUploader/Utils/RelayCommand.cs
@@ -1,7 +1,7 @@
using System;
using System.Windows.Input;
-namespace RomeOnlinePartner
+namespace ProManagerPartner
{
public class RelayCommand : ICommand
{
diff --git a/BodyshopUploader/Utils/ScheduledTaskConfig.cs b/BodyshopUploader/Utils/ScheduledTaskConfig.cs
index 3054032..1e2fa47 100644
--- a/BodyshopUploader/Utils/ScheduledTaskConfig.cs
+++ b/BodyshopUploader/Utils/ScheduledTaskConfig.cs
@@ -7,7 +7,7 @@ using System.Threading.Tasks;
using Microsoft.Win32.TaskScheduler;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class ScheduledTaskConfig
{
@@ -19,12 +19,12 @@ namespace RomeOnlinePartner.Utils
try
{
- Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("Rome Online Partner - Paint Scale Connection Export");
+ Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("ProManager Partner - Paint Scale Connection Export");
if (existingTask != null)
{
- TaskService.Instance.RootFolder.DeleteTask("Rome Online Partner - Paint Scale Connection Export");
+ TaskService.Instance.RootFolder.DeleteTask("ProManager Partner - Paint Scale Connection Export");
}
- Microsoft.Win32.TaskScheduler.Task newTask = TaskService.Instance.AddTask("Rome Online Partner - Paint Scale Connection Export", QuickTriggerType.Hourly, "powershell.exe", @"-ExecutionPolicy Bypass -File " + AppMetaData.globalScriptsPath + @"\PaintScaleExport.ps1");
+ Microsoft.Win32.TaskScheduler.Task newTask = TaskService.Instance.AddTask("ProManager Partner - Paint Scale Connection Export", QuickTriggerType.Hourly, "powershell.exe", @"-ExecutionPolicy Bypass -File " + AppMetaData.globalScriptsPath + @"\PaintScaleExport.ps1");
newTask.Run();
@@ -41,12 +41,12 @@ namespace RomeOnlinePartner.Utils
try
{
- Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("Rome Online Partner - ARMS");
+ Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("ProManager Partner - ARMS");
if (existingTask != null)
{
- TaskService.Instance.RootFolder.DeleteTask("Rome Online Partner - ARMS");
+ TaskService.Instance.RootFolder.DeleteTask("ProManager Partner - ARMS");
}
- Microsoft.Win32.TaskScheduler.Task newTask = TaskService.Instance.AddTask("Rome Online Partner - ARMS", QuickTriggerType.Daily, "powershell.exe", @"-ExecutionPolicy Bypass -File " + AppMetaData.globalScriptsPath + @"\ArmsExport.ps1");
+ Microsoft.Win32.TaskScheduler.Task newTask = TaskService.Instance.AddTask("ProManager Partner - ARMS", QuickTriggerType.Daily, "powershell.exe", @"-ExecutionPolicy Bypass -File " + AppMetaData.globalScriptsPath + @"\ArmsExport.ps1");
newTask.Run();
diff --git a/BodyshopUploader/Utils/Scripts/ArmsExport.ps1 b/BodyshopUploader/Utils/Scripts/ArmsExport.ps1
index 1a8c43e..05b13bf 100644
--- a/BodyshopUploader/Utils/Scripts/ArmsExport.ps1
+++ b/BodyshopUploader/Utils/Scripts/ArmsExport.ps1
@@ -1,7 +1,7 @@
#Verify that the partner is running. If not, strat it.
-if((Get-Process -Name RomeOnlinePartner -ErrorAction SilentlyContinue) -eq $null){
- & "$Env:USERPROFILE\AppData\Local\RomeOnlinePartner\RomeOnlinePartner.exe"
+if((Get-Process -Name ProManagerPartner -ErrorAction SilentlyContinue) -eq $null){
+ & "$Env:USERPROFILE\AppData\Local\ProManagerPartner\ProManagerPartner.exe"
}
$PSversion = $PSVersionTable.PSVersion.Major
@@ -11,7 +11,7 @@ function v2 {
# Post request to the partner to trigger the export.
Invoke-WebRequest -Uri http://localhost:1337/arms/rodata/ -Method POST
#Start the Arms Uploader.
-Start-Process -FilePath "C:\Rome\Applications\ARMSUploader\ROUpload.exe"
+Start-Process -FilePath "C:\Web-Est\Applications\ARMSUploader\ROUpload.exe"
}
function v1 {
@@ -23,7 +23,7 @@ ResponseStream = $Response.GetResponseStream()
ReadStream = New-Object System.IO.StreamReader $ResponseStream
#Data=$ReadStream.ReadToEnd()
#Start the Arms Uploader.
-Start-Process -FilePath "C:\Rome\Applications\ARMSUploader\ROUpload.exe"
+Start-Process -FilePath "C:\Web-Est\Applications\ARMSUploader\ROUpload.exe"
}
diff --git a/BodyshopUploader/Utils/Scripts/PaintScaleExport.ps1 b/BodyshopUploader/Utils/Scripts/PaintScaleExport.ps1
index d14a984..a03e80e 100644
--- a/BodyshopUploader/Utils/Scripts/PaintScaleExport.ps1
+++ b/BodyshopUploader/Utils/Scripts/PaintScaleExport.ps1
@@ -1,7 +1,7 @@
#Verify that the partner is running. If not, strat it.
-if((Get-Process -Name RomeOnlinePartner -ErrorAction SilentlyContinue) -eq $null){
- & "$Env:USERPROFILE\AppData\Local\RomeOnlinePartner\RomeOnlinePartner.exe"
+if((Get-Process -Name ProManagerPartner -ErrorAction SilentlyContinue) -eq $null){
+ & "$Env:USERPROFILE\AppData\Local\ProManagerPartner\ProManagerPartner.exe"
}
$PSversion = $PSVersionTable.PSVersion.Major
diff --git a/BodyshopUploader/Utils/Scripts/ProtocolReg.reg b/BodyshopUploader/Utils/Scripts/ProtocolReg.reg
index 33a481d..2ed4f53 100644
--- a/BodyshopUploader/Utils/Scripts/ProtocolReg.reg
+++ b/BodyshopUploader/Utils/Scripts/ProtocolReg.reg
@@ -12,7 +12,7 @@ Windows Registry Editor Version 5.00
[HKEY_CURRENT_USER\Software\Classes\imexmedia\shell\open]
[HKEY_CURRENT_USER\Software\Classes\imexmedia\shell\open\command]
-@="\"C:\\Rome\\PartnerScripts\\imexmedia.bat\" %1"
+@="\"C:\\Web-Est\\PartnerScripts\\imexmedia.bat\" %1"
[HKEY_LOCAL_MACHINE\SOFTWARE\Policies\Microsoft\Edge]
"ExternalProtocolDialogShowAlwaysOpenCheckbox"=dword:00000001
diff --git a/BodyshopUploader/Utils/SquirrelAwareHelper.cs b/BodyshopUploader/Utils/SquirrelAwareHelper.cs
index 68fd177..9e9f4f8 100644
--- a/BodyshopUploader/Utils/SquirrelAwareHelper.cs
+++ b/BodyshopUploader/Utils/SquirrelAwareHelper.cs
@@ -9,7 +9,7 @@ using Microsoft.Win32.TaskScheduler;
using System.IO;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class SquirrelAwareHelper
{
@@ -69,10 +69,10 @@ namespace RomeOnlinePartner.Utils
//The paint scale accidentally got added to all people running v31. This was added to remove it.
try
{
- Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("Rome Online Partner - Paint Scale Connection");
+ Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("ProManager Partner - Paint Scale Connection");
if (existingTask != null)
{
- TaskService.Instance.RootFolder.DeleteTask("Rome Online Partner - Paint Scale Connection");
+ TaskService.Instance.RootFolder.DeleteTask("ProManager Partner - Paint Scale Connection");
}
}
catch (Exception ex)
@@ -150,10 +150,10 @@ namespace RomeOnlinePartner.Utils
mgr.RemoveShortcutForThisExe();
try
{
- Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("Rome Online Partner - Paint Scale Connection Export"); //This is the old scale path. This was accidentally added for everyone.
+ Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("ProManager Partner - Paint Scale Connection Export"); //This is the old scale path. This was accidentally added for everyone.
if (existingTask != null)
{
- TaskService.Instance.RootFolder.DeleteTask("Rome Online Partner - Paint Scale Connection");
+ TaskService.Instance.RootFolder.DeleteTask("ProManager Partner - Paint Scale Connection");
}
}
catch (Exception ex)
@@ -162,10 +162,10 @@ namespace RomeOnlinePartner.Utils
}
try
{
- Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("Rome Online Partner - Paint Scale Connection Export");
+ Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("ProManager Partner - Paint Scale Connection Export");
if (existingTask != null)
{
- TaskService.Instance.RootFolder.DeleteTask("Rome Online Partner - Paint Scale Connection Export");
+ TaskService.Instance.RootFolder.DeleteTask("ProManager Partner - Paint Scale Connection Export");
}
}
catch (Exception ex)
@@ -174,10 +174,10 @@ namespace RomeOnlinePartner.Utils
}
try
{
- Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("Rome Online Partner - ARMS");
+ Microsoft.Win32.TaskScheduler.Task existingTask = TaskService.Instance.FindTask("ProManager Partner - ARMS");
if (existingTask != null)
{
- TaskService.Instance.RootFolder.DeleteTask("Rome Online Partner - ARMS");
+ TaskService.Instance.RootFolder.DeleteTask("ProManager Partner - ARMS");
}
}
catch (Exception ex)
diff --git a/BodyshopUploader/Utils/TrayIcon.cs b/BodyshopUploader/Utils/TrayIcon.cs
index cf8b00c..e3c8a13 100644
--- a/BodyshopUploader/Utils/TrayIcon.cs
+++ b/BodyshopUploader/Utils/TrayIcon.cs
@@ -5,7 +5,7 @@ using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public class OpenMainWindowCommand : ICommand
{
diff --git a/BodyshopUploader/Utils/UiConverters.cs b/BodyshopUploader/Utils/UiConverters.cs
index 6175633..c881b76 100644
--- a/BodyshopUploader/Utils/UiConverters.cs
+++ b/BodyshopUploader/Utils/UiConverters.cs
@@ -7,7 +7,7 @@ using System.Threading.Tasks;
using System.Windows;
using System.Windows.Data;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public class BoolVisibilityConverter : IValueConverter
{
diff --git a/BodyshopUploader/Utils/UpdateHandler.cs b/BodyshopUploader/Utils/UpdateHandler.cs
index 9f84233..6a30d38 100644
--- a/BodyshopUploader/Utils/UpdateHandler.cs
+++ b/BodyshopUploader/Utils/UpdateHandler.cs
@@ -10,7 +10,7 @@ using System.Text;
using System.Threading.Tasks;
using System.Windows;
-namespace RomeOnlinePartner.Utils
+namespace ProManagerPartner.Utils
{
public static class UpdateHandler
{
@@ -35,7 +35,7 @@ namespace RomeOnlinePartner.Utils
private static NLog.Logger logger = NLog.LogManager.GetCurrentClassLogger();
- public const string UpdatePath = @"http://partner.romeonline.io/";
+ public const string UpdatePath = @"http://partner.promanager.web-est.com/";
public static async Task AreUpdatesAvailable()
{
diff --git a/BodyshopUploader/ViewModels/LoginViewModel.commands.cs b/BodyshopUploader/ViewModels/LoginViewModel.commands.cs
index e267524..b5c1f77 100644
--- a/BodyshopUploader/ViewModels/LoginViewModel.commands.cs
+++ b/BodyshopUploader/ViewModels/LoginViewModel.commands.cs
@@ -2,7 +2,7 @@
using System.Windows;
using System.Windows.Input;
-namespace RomeOnlinePartner.ViewModels
+namespace ProManagerPartner.ViewModels
{
public partial class LoginViewModel : BaseViewModel
{
diff --git a/BodyshopUploader/ViewModels/LoginViewModel.cs b/BodyshopUploader/ViewModels/LoginViewModel.cs
index b55dccc..a467046 100644
--- a/BodyshopUploader/ViewModels/LoginViewModel.cs
+++ b/BodyshopUploader/ViewModels/LoginViewModel.cs
@@ -7,7 +7,7 @@ using System.Threading.Tasks;
using System.Windows;
-namespace RomeOnlinePartner.ViewModels
+namespace ProManagerPartner.ViewModels
{
public partial class LoginViewModel : BaseViewModel
{
diff --git a/BodyshopUploader/ViewModels/LoginViewModel.props.cs b/BodyshopUploader/ViewModels/LoginViewModel.props.cs
index b988e13..f3c669e 100644
--- a/BodyshopUploader/ViewModels/LoginViewModel.props.cs
+++ b/BodyshopUploader/ViewModels/LoginViewModel.props.cs
@@ -6,7 +6,7 @@ using System.Security;
using System.Text;
using System.Threading.Tasks;
-namespace RomeOnlinePartner.ViewModels
+namespace ProManagerPartner.ViewModels
{
public partial class LoginViewModel : BaseViewModel
{
diff --git a/BodyshopUploader/ViewModels/MainViewModel.commands.cs b/BodyshopUploader/ViewModels/MainViewModel.commands.cs
index dafd50d..326812b 100644
--- a/BodyshopUploader/ViewModels/MainViewModel.commands.cs
+++ b/BodyshopUploader/ViewModels/MainViewModel.commands.cs
@@ -2,7 +2,7 @@
using System.Windows;
using System.Windows.Input;
-namespace RomeOnlinePartner.ViewModels
+namespace ProManagerPartner.ViewModels
{
public partial class MainViewModel : BaseViewModel
{
diff --git a/BodyshopUploader/ViewModels/MainViewModel.cs b/BodyshopUploader/ViewModels/MainViewModel.cs
index 92144de..00e94b5 100644
--- a/BodyshopUploader/ViewModels/MainViewModel.cs
+++ b/BodyshopUploader/ViewModels/MainViewModel.cs
@@ -1,5 +1,5 @@
-using RomeOnlinePartner.Models;
-using RomeOnlinePartner.Utils.Growls;
+using ProManagerPartner.Models;
+using ProManagerPartner.Utils.Growls;
using GraphQL.Client;
using GraphQL;
using Newtonsoft.Json;
@@ -16,7 +16,7 @@ using Firebase.Auth;
using ToastNotifications.Messages;
using Microsoft.Win32;
-namespace RomeOnlinePartner.ViewModels
+namespace ProManagerPartner.ViewModels
{
public partial class MainViewModel : BaseViewModel
{
@@ -109,7 +109,7 @@ namespace RomeOnlinePartner.ViewModels
}
- // string msg = "An update to Rome Online Partner is Available. It will be automatically downloaded and applied.";
+ // string msg = "An update to ProManager Partner is Available. It will be automatically downloaded and applied.";
// Utils.Notifications.notifier.ShowInformation(msg);
// logger.Debug("Updates are available! Installing.");
// try
@@ -399,7 +399,7 @@ namespace RomeOnlinePartner.ViewModels
logger.Trace(newLine);
}
- private FirebaseAuthLink al = RomeOnlinePartner.Utils.Auth.authlink;
+ private FirebaseAuthLink al = ProManagerPartner.Utils.Auth.authlink;
public async Task TestGql()
{
diff --git a/BodyshopUploader/ViewModels/MainViewModel.props.cs b/BodyshopUploader/ViewModels/MainViewModel.props.cs
index 7f2df56..2e50867 100644
--- a/BodyshopUploader/ViewModels/MainViewModel.props.cs
+++ b/BodyshopUploader/ViewModels/MainViewModel.props.cs
@@ -4,11 +4,11 @@ using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
-using RomeOnlinePartner.Utils.Growls;
-using RomeOnlinePartner.Models;
+using ProManagerPartner.Utils.Growls;
+using ProManagerPartner.Models;
using System.Reflection;
-namespace RomeOnlinePartner.ViewModels
+namespace ProManagerPartner.ViewModels
{
public partial class MainViewModel : BaseViewModel
{
diff --git a/BodyshopUploader/Views/Login.xaml b/BodyshopUploader/Views/Login.xaml
index 0754fa1..c6ea8e6 100644
--- a/BodyshopUploader/Views/Login.xaml
+++ b/BodyshopUploader/Views/Login.xaml
@@ -1,16 +1,16 @@
-
-
-
-
/// Interaction logic for Login.xaml
diff --git a/BodyshopUploader/Views/Main.xaml b/BodyshopUploader/Views/Main.xaml
index 4b9ffc9..d95daf7 100644
--- a/BodyshopUploader/Views/Main.xaml
+++ b/BodyshopUploader/Views/Main.xaml
@@ -1,13 +1,13 @@
-
-
+ Content="{x:Static p:Resources.Label_ConfigurePaintScale}" />-->
-
+ Content="{x:Static p:Resources.Label_ConfigureArmsExport}" />-->
@@ -253,7 +253,7 @@
ContentStringFormat=""
Grid.Column="1"/>
-
@@ -268,8 +268,8 @@
-
- -->
+
+
-
@@ -326,8 +326,8 @@
-
- -->
+
/// Interaction logic for Main.xaml
diff --git a/BodyshopUploader/Properties/Resources.Designer.cs b/BodyshopUploader/Properties/Resources.Designer.cs
index 018a55c..05caeb2 100644
--- a/BodyshopUploader/Properties/Resources.Designer.cs
+++ b/BodyshopUploader/Properties/Resources.Designer.cs
@@ -8,7 +8,7 @@
//
//------------------------------------------------------------------------------
-namespace RomeOnlinePartner.Properties {
+namespace ProManagerPartner.Properties {
using System;
@@ -39,7 +39,7 @@ namespace RomeOnlinePartner.Properties {
public static global::System.Resources.ResourceManager ResourceManager {
get {
if (object.ReferenceEquals(resourceMan, null)) {
- global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("RomeOnlinePartner.Properties.Resources", typeof(Resources).Assembly);
+ global::System.Resources.ResourceManager temp = new global::System.Resources.ResourceManager("ProManagerPartner.Properties.Resources", typeof(Resources).Assembly);
resourceMan = temp;
}
return resourceMan;
@@ -466,7 +466,7 @@ namespace RomeOnlinePartner.Properties {
}
///
/// Looks up a localized string similar to Please do not close Rome Online or Rome Partner during the connection process..
///
public static string Msg_QbConnection_Msg {
get {
@@ -511,7 +511,7 @@ namespace RomeOnlinePartner.Properties {
}
///
/// Looks up a localized string similar to Login - Rome Online Partner.
///
public static string Title_Login {
get {
@@ -520,7 +520,7 @@ namespace RomeOnlinePartner.Properties {
}
///
/// Looks up a localized string similar to Rome Online Partner.
///
public static string Title_Login_Header {
get {
@@ -529,7 +529,7 @@ namespace RomeOnlinePartner.Properties {
}
///
- /// Looks up a localized string similar to Rome Online Partner | Rome Technologies.
+ /// Looks up a localized string similar to ProManager Partner | Web-Est.
///
public static string Title_Main {
get {
@@ -466,7 +466,7 @@ namespace RomeOnlinePartner.Properties {
}
///
- /// Looks up a localized string similar to Please do not close Rome Online or Rome Partner during the connection process..
+ /// Looks up a localized string similar to Please do not close ProManager or ProManager Partner during the connection process..
///
public static string Msg_QbConnection_Msg {
@@ -511,7 +511,7 @@ namespace RomeOnlinePartner.Properties {
}
///
- /// Looks up a localized string similar to Login - Rome Online Partner.
+ /// Looks up a localized string similar to Login - ProManager Partner.
///
public static string Title_Login {
@@ -520,7 +520,7 @@ namespace RomeOnlinePartner.Properties {
}
///
- /// Looks up a localized string similar to Rome Online Partner.
+ /// Looks up a localized string similar to ProManager Partner.
///
public static string Title_Login_Header {
diff --git a/BodyshopUploader/favicon.ico b/BodyshopUploader/favicon.ico
index 2280b30..f0c442e 100644
Binary files a/BodyshopUploader/favicon.ico and b/BodyshopUploader/favicon.ico differ